
_itf_embedded = dict()

def Register(key, value):
    """ Register an embedded class """
    _itf_embedded[key] = value

def Lookup(key):
    """ Lookup an embedded class """
    return _itf_embedded.get(key, None)



def marshal(output, name, value):
    func = name + '__marshal'
    getattr(output, func)(value)

def demarshal(input, name):
    func = name + '__demarshal'
    return getattr(input, func)()

def check(type, value):
    if isinstance(type, str):
        if type == 'char':
            if not isinstance(value, str):
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
            if len(value) != 1:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'wchar':
            if not isinstance(value, basestring):
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
            if len(value) != 1:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'octet':
            if value < 0 or value > 255:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'short':
            if value < -32768 or value > 32767:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'unsigned_short':
            if value < 0 or value > 65535:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'long':
            if value < -2147483648 or value > 2147483647:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'unsigned_long':
            if value < 0 or value > 4294967295L:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'long_long':
            if value < -9223372036854775808L or value > 9223372036854775807L:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'unsigned_long_long':
            if value < 0 or value > 18446744073709551615L:
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'float':
            pass
        elif type == 'double':
            pass
        elif type == 'long_double':
            pass
        elif type == 'boolean':
            pass
        elif type == 'string':
            if not isinstance(value, str):
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        elif type == 'wstring':
            if not isinstance(value, basestring):
                raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)
        else:
            raise "Internal Error: %s" % type
    else:
        if isinstance(value, type) == False:
            raise SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA_COMPLETED_MAYBE)

class UserException(Exception):
    """ An IDL exception is translated into a Python class derived from CORBA.UserException. """
    pass

class SystemException(Exception):
    """ CORBA.SystemException """

    def __init__(self, repos_id, minor, completed):
        self.repos_id = repos_id
        self.minor = minor
        self.completed = completed

    def __str__(self):
        return self.repos_id

CORBA_COMPLETED_YES = 0     # The object implementation has completed
                            # processing prior to the exception being raised.
CORBA_COMPLETED_NO = 1      # The object implementation was never initiated
                            # prior to the exception being raised.
CORBA_COMPLETED_MAYBE = 2   # The status of implementation completion is
                            # indeterminate.

class Enum(object):
    """ base class for IDL enum """

    def __init__(self, str, val):
        self._val = val
        self._enum_str[val] = str
        self._enum[val] = self

    def marshal(self, output):
        output.long__marshal(self._val)

    def demarshal(cls, input):
        val = input.long__demarshal()
        if cls._enum.has_key(val):
            return cls._enum[val]
        else:
            raise 'CORBA.MARSHAL'
    demarshal = classmethod(demarshal)

    def __repr__(self):
        return self._enum_str[self._val]





import Cplx

class MyCalcCplx(Cplx.CalcCplx):

    def Add(self, val1, val2):
        return Cplx.Complex(val1.re + val2.re, val1.im + val2.im)

    def Sub(self, val1, val2):
        return Cplx.Complex(val1.re - val2.re, val1.im - val2.im)




import unittest

from _Calc import *

class Test(unittest.TestCase):
	def setUp(self):
		self.c = Calc()

	def test1(self):
		ret = self.c.Add(5, 2)
		self.assertEqual(7, ret)

	def test2(self):
		ret = self.c.Mul(5, 2)
		self.assertEqual(10, ret)

	def test3(self):
		ret = self.c.Mul(5, 0)
		self.assertEqual(0, ret)

	def test4(self):
		ret = self.c.Sub(5, 2)
		self.assertEqual(3, ret)

	def test5(self):
		ret = self.c.Div(5, 2)
		self.assertEqual(2, ret)

	def test6(self):
		ret = self.c.Div(0, 2)
		self.assertEqual(0, ret)

	def test7(self):
		try:
			ret = self.c.Div(5, 0)
			self.fail()
		except Calc.DivisionByZero:
			self.failUnless(1)

if __name__ == '__main__' :
	unittest.main()



#   This file was generated (by idl2py.pl). DO NOT modify it.
# From file : giop.idl, 9058 octets, Fri Aug 08 13:00:54 2003

import PyIDL as CORBA

import PyIDL.iop as IOP

""" Module IDL:omg.org/GIOP:1.0 """

class Version(object):
    """ Struct IDL:omg.org/GIOP/Version:1.0 """

    def __init__(self, major, minor):
        self._setmajor(major)
        self._setminor(minor)

    def _setmajor(self, major):
        CORBA.check('octet', major)
        self._major = major

    def _getmajor(self):
        return self._major

    major = property(fset=_setmajor, fget=_getmajor)

    def _setminor(self, minor):
        CORBA.check('octet', minor)
        self._minor = minor

    def _getminor(self):
        return self._minor

    minor = property(fset=_setminor, fget=_getminor)

    def marshal(self, output):
            CORBA.marshal(output, 'octet', self.major)
            CORBA.marshal(output, 'octet', self.minor)

    def demarshal(cls, input):
            major = CORBA.demarshal(input, 'octet')
            minor = CORBA.demarshal(input, 'octet')
            return cls(major, minor)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.major != obj.major :
            return False
        if self.minor != obj.minor :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('octet major=' + repr(self.major))
        lst.append('octet minor=' + repr(self.minor))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct Version {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/Version:1.0'

    corba_id = classmethod(_get_id)

class Principal(str):
    """ Typedef IDL:omg.org/GIOP/Principal:1.0 """

    def marshal(self, output):
        CORBA.marshal(output, 'long', len(self))
        for e in self :
            CORBA.marshal(output, 'octet', ord(e))

    def demarshal(cls, input):
        nb = CORBA.demarshal(input, 'long')
        lst = []
        for i in xrange(nb) :
            lst.append(CORBA.demarshal(input, 'octet'))
        val = ''.join(map(chr, lst))
        return cls(val)
    demarshal = classmethod(demarshal)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/Principal:1.0'

    corba_id = classmethod(_get_id)

class MsgType_1_1(CORBA.Enum):
    """ Enum IDL:omg.org/GIOP/MsgType_1_1:1.0 """

    _enum_str = dict()
    _enum = dict()

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/MsgType_1_1:1.0'

    corba_id = classmethod(_get_id)

Request = MsgType_1_1('Request', 0)
Reply = MsgType_1_1('Reply', 1)
CancelRequest = MsgType_1_1('CancelRequest', 2)
LocateRequest = MsgType_1_1('LocateRequest', 3)
LocateReply = MsgType_1_1('LocateReply', 4)
CloseConnection = MsgType_1_1('CloseConnection', 5)
MessageError = MsgType_1_1('MessageError', 6)
Fragment = MsgType_1_1('Fragment', 7)

# Typedef: IDL:omg.org/GIOP/MsgType_1_2:1.0
MsgType_1_2 = MsgType_1_1

# Typedef: IDL:omg.org/GIOP/MsgType_1_3:1.0
MsgType_1_3 = MsgType_1_1

class MessageHeader_1_0(object):
    """ Struct IDL:omg.org/GIOP/MessageHeader_1_0:1.0 """

    def __init__(self, magic, GIOP_version, byte_order, message_type, message_size):
        self._setmagic(magic)
        self._setGIOP_version(GIOP_version)
        self._setbyte_order(byte_order)
        self._setmessage_type(message_type)
        self._setmessage_size(message_size)

    def _setmagic(self, magic):
        _e0 = magic
        if len(_e0) != 4 :
            raise CORBA.SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA.CORBA_COMPLETED_MAYBE)
        for _e1 in _e0 :
            CORBA.check('char', _e1)
        self._magic = magic

    def _getmagic(self):
        return self._magic

    magic = property(fset=_setmagic, fget=_getmagic)

    def _setGIOP_version(self, GIOP_version):
        CORBA.check(Version, GIOP_version)
        self._GIOP_version = GIOP_version

    def _getGIOP_version(self):
        return self._GIOP_version

    GIOP_version = property(fset=_setGIOP_version, fget=_getGIOP_version)

    def _setbyte_order(self, byte_order):
        CORBA.check('boolean', byte_order)
        self._byte_order = byte_order

    def _getbyte_order(self):
        return self._byte_order

    byte_order = property(fset=_setbyte_order, fget=_getbyte_order)

    def _setmessage_type(self, message_type):
        CORBA.check('octet', message_type)
        self._message_type = message_type

    def _getmessage_type(self):
        return self._message_type

    message_type = property(fset=_setmessage_type, fget=_getmessage_type)

    def _setmessage_size(self, message_size):
        CORBA.check('unsigned_long', message_size)
        self._message_size = message_size

    def _getmessage_size(self):
        return self._message_size

    message_size = property(fset=_setmessage_size, fget=_getmessage_size)

    def marshal(self, output):
            _e0 = self.magic
            for _e1 in _e0 :
                CORBA.marshal(output, 'char', _e1)
            self.GIOP_version.marshal(output)
            CORBA.marshal(output, 'boolean', self.byte_order)
            CORBA.marshal(output, 'octet', self.message_type)
            CORBA.marshal(output, 'unsigned_long', self.message_size)

    def demarshal(cls, input):
            _lst0 = []
            for _i0 in xrange(4) :
                _lst0.append(CORBA.demarshal(input, 'char'))
            _lst0 = ''.join(_lst0)
            magic = _lst0
            GIOP_version = Version.demarshal(input)
            byte_order = CORBA.demarshal(input, 'boolean')
            message_type = CORBA.demarshal(input, 'octet')
            message_size = CORBA.demarshal(input, 'unsigned_long')
            return cls(magic, GIOP_version, byte_order, message_type, message_size)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.magic != obj.magic :
            return False
        if self.GIOP_version != obj.GIOP_version :
            return False
        if self.byte_order != obj.byte_order :
            return False
        if self.message_type != obj.message_type :
            return False
        if self.message_size != obj.message_size :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('char[4] magic=' + repr(self.magic))
        lst.append('Version GIOP_version=' + repr(self.GIOP_version))
        lst.append('boolean byte_order=' + repr(self.byte_order))
        lst.append('octet message_type=' + repr(self.message_type))
        lst.append('unsigned_long message_size=' + repr(self.message_size))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct MessageHeader_1_0 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/MessageHeader_1_0:1.0'

    corba_id = classmethod(_get_id)

class MessageHeader_1_1(object):
    """ Struct IDL:omg.org/GIOP/MessageHeader_1_1:1.0 """

    def __init__(self, magic, GIOP_version, flags, message_type, message_size):
        self._setmagic(magic)
        self._setGIOP_version(GIOP_version)
        self._setflags(flags)
        self._setmessage_type(message_type)
        self._setmessage_size(message_size)

    def _setmagic(self, magic):
        _e0 = magic
        if len(_e0) != 4 :
            raise CORBA.SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA.CORBA_COMPLETED_MAYBE)
        for _e1 in _e0 :
            CORBA.check('char', _e1)
        self._magic = magic

    def _getmagic(self):
        return self._magic

    magic = property(fset=_setmagic, fget=_getmagic)

    def _setGIOP_version(self, GIOP_version):
        CORBA.check(Version, GIOP_version)
        self._GIOP_version = GIOP_version

    def _getGIOP_version(self):
        return self._GIOP_version

    GIOP_version = property(fset=_setGIOP_version, fget=_getGIOP_version)

    def _setflags(self, flags):
        CORBA.check('octet', flags)
        self._flags = flags

    def _getflags(self):
        return self._flags

    flags = property(fset=_setflags, fget=_getflags)

    def _setmessage_type(self, message_type):
        CORBA.check('octet', message_type)
        self._message_type = message_type

    def _getmessage_type(self):
        return self._message_type

    message_type = property(fset=_setmessage_type, fget=_getmessage_type)

    def _setmessage_size(self, message_size):
        CORBA.check('unsigned_long', message_size)
        self._message_size = message_size

    def _getmessage_size(self):
        return self._message_size

    message_size = property(fset=_setmessage_size, fget=_getmessage_size)

    def marshal(self, output):
            _e0 = self.magic
            for _e1 in _e0 :
                CORBA.marshal(output, 'char', _e1)
            self.GIOP_version.marshal(output)
            CORBA.marshal(output, 'octet', self.flags)
            CORBA.marshal(output, 'octet', self.message_type)
            CORBA.marshal(output, 'unsigned_long', self.message_size)

    def demarshal(cls, input):
            _lst0 = []
            for _i0 in xrange(4) :
                _lst0.append(CORBA.demarshal(input, 'char'))
            _lst0 = ''.join(_lst0)
            magic = _lst0
            GIOP_version = Version.demarshal(input)
            flags = CORBA.demarshal(input, 'octet')
            message_type = CORBA.demarshal(input, 'octet')
            message_size = CORBA.demarshal(input, 'unsigned_long')
            return cls(magic, GIOP_version, flags, message_type, message_size)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.magic != obj.magic :
            return False
        if self.GIOP_version != obj.GIOP_version :
            return False
        if self.flags != obj.flags :
            return False
        if self.message_type != obj.message_type :
            return False
        if self.message_size != obj.message_size :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('char[4] magic=' + repr(self.magic))
        lst.append('Version GIOP_version=' + repr(self.GIOP_version))
        lst.append('octet flags=' + repr(self.flags))
        lst.append('octet message_type=' + repr(self.message_type))
        lst.append('unsigned_long message_size=' + repr(self.message_size))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct MessageHeader_1_1 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/MessageHeader_1_1:1.0'

    corba_id = classmethod(_get_id)

class MessageHeader_1_2(MessageHeader_1_1):
    """ Typedef IDL:omg.org/GIOP/MessageHeader_1_2:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], MessageHeader_1_1):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(MessageHeader_1_2, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/MessageHeader_1_2:1.0'

    corba_id = classmethod(_get_id)

class MessageHeader_1_3(MessageHeader_1_1):
    """ Typedef IDL:omg.org/GIOP/MessageHeader_1_3:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], MessageHeader_1_1):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(MessageHeader_1_3, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/MessageHeader_1_3:1.0'

    corba_id = classmethod(_get_id)

class RequestHeader_1_0(object):
    """ Struct IDL:omg.org/GIOP/RequestHeader_1_0:1.0 """

    def __init__(self, service_context, request_id, response_expected, object_key, operation, requesting_principal):
        self._setservice_context(service_context)
        self._setrequest_id(request_id)
        self._setresponse_expected(response_expected)
        self._setobject_key(object_key)
        self._setoperation(operation)
        self._setrequesting_principal(requesting_principal)

    def _setservice_context(self, service_context):
        CORBA.check(IOP.ServiceContextList, service_context)
        self._service_context = service_context

    def _getservice_context(self):
        return self._service_context

    service_context = property(fset=_setservice_context, fget=_getservice_context)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def _setresponse_expected(self, response_expected):
        CORBA.check('boolean', response_expected)
        self._response_expected = response_expected

    def _getresponse_expected(self):
        return self._response_expected

    response_expected = property(fset=_setresponse_expected, fget=_getresponse_expected)

    def _setobject_key(self, object_key):
        _e0 = object_key
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._object_key = object_key

    def _getobject_key(self):
        return self._object_key

    object_key = property(fset=_setobject_key, fget=_getobject_key)

    def _setoperation(self, operation):
        CORBA.check('string', operation)
        self._operation = operation

    def _getoperation(self):
        return self._operation

    operation = property(fset=_setoperation, fget=_getoperation)

    def _setrequesting_principal(self, requesting_principal):
        CORBA.check(Principal, requesting_principal)
        self._requesting_principal = requesting_principal

    def _getrequesting_principal(self):
        return self._requesting_principal

    requesting_principal = property(fset=_setrequesting_principal, fget=_getrequesting_principal)

    def marshal(self, output):
            self.service_context.marshal(output)
            CORBA.marshal(output, 'unsigned_long', self.request_id)
            CORBA.marshal(output, 'boolean', self.response_expected)
            _e0 = self.object_key
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))
            CORBA.marshal(output, 'string', self.operation)
            self.requesting_principal.marshal(output)

    def demarshal(cls, input):
            service_context = IOP.ServiceContextList.demarshal(input)
            request_id = CORBA.demarshal(input, 'unsigned_long')
            response_expected = CORBA.demarshal(input, 'boolean')
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            object_key = _lst0
            operation = CORBA.demarshal(input, 'string')
            requesting_principal = Principal.demarshal(input)
            return cls(service_context, request_id, response_expected, object_key, operation, requesting_principal)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.service_context != obj.service_context :
            return False
        if self.request_id != obj.request_id :
            return False
        if self.response_expected != obj.response_expected :
            return False
        if self.object_key != obj.object_key :
            return False
        if self.operation != obj.operation :
            return False
        if self.requesting_principal != obj.requesting_principal :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('ServiceContextList service_context=' + repr(self.service_context))
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        lst.append('boolean response_expected=' + repr(self.response_expected))
        lst.append('octet<> object_key=' + repr(self.object_key))
        lst.append('string operation=' + repr(self.operation))
        lst.append('Principal requesting_principal=' + repr(self.requesting_principal))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct RequestHeader_1_0 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/RequestHeader_1_0:1.0'

    corba_id = classmethod(_get_id)

class RequestHeader_1_1(object):
    """ Struct IDL:omg.org/GIOP/RequestHeader_1_1:1.0 """

    def __init__(self, service_context, request_id, response_expected, reserved, object_key, operation, requesting_principal):
        self._setservice_context(service_context)
        self._setrequest_id(request_id)
        self._setresponse_expected(response_expected)
        self._setreserved(reserved)
        self._setobject_key(object_key)
        self._setoperation(operation)
        self._setrequesting_principal(requesting_principal)

    def _setservice_context(self, service_context):
        CORBA.check(IOP.ServiceContextList, service_context)
        self._service_context = service_context

    def _getservice_context(self):
        return self._service_context

    service_context = property(fset=_setservice_context, fget=_getservice_context)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def _setresponse_expected(self, response_expected):
        CORBA.check('boolean', response_expected)
        self._response_expected = response_expected

    def _getresponse_expected(self):
        return self._response_expected

    response_expected = property(fset=_setresponse_expected, fget=_getresponse_expected)

    def _setreserved(self, reserved):
        _e0 = reserved
        if len(_e0) != 3 :
            raise CORBA.SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA.CORBA_COMPLETED_MAYBE)
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._reserved = reserved

    def _getreserved(self):
        return self._reserved

    reserved = property(fset=_setreserved, fget=_getreserved)

    def _setobject_key(self, object_key):
        _e0 = object_key
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._object_key = object_key

    def _getobject_key(self):
        return self._object_key

    object_key = property(fset=_setobject_key, fget=_getobject_key)

    def _setoperation(self, operation):
        CORBA.check('string', operation)
        self._operation = operation

    def _getoperation(self):
        return self._operation

    operation = property(fset=_setoperation, fget=_getoperation)

    def _setrequesting_principal(self, requesting_principal):
        CORBA.check(Principal, requesting_principal)
        self._requesting_principal = requesting_principal

    def _getrequesting_principal(self):
        return self._requesting_principal

    requesting_principal = property(fset=_setrequesting_principal, fget=_getrequesting_principal)

    def marshal(self, output):
            self.service_context.marshal(output)
            CORBA.marshal(output, 'unsigned_long', self.request_id)
            CORBA.marshal(output, 'boolean', self.response_expected)
            _e0 = self.reserved
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))
            _e0 = self.object_key
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))
            CORBA.marshal(output, 'string', self.operation)
            self.requesting_principal.marshal(output)

    def demarshal(cls, input):
            service_context = IOP.ServiceContextList.demarshal(input)
            request_id = CORBA.demarshal(input, 'unsigned_long')
            response_expected = CORBA.demarshal(input, 'boolean')
            _lst0 = []
            for _i0 in xrange(3) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            reserved = _lst0
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            object_key = _lst0
            operation = CORBA.demarshal(input, 'string')
            requesting_principal = Principal.demarshal(input)
            return cls(service_context, request_id, response_expected, reserved, object_key, operation, requesting_principal)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.service_context != obj.service_context :
            return False
        if self.request_id != obj.request_id :
            return False
        if self.response_expected != obj.response_expected :
            return False
        if self.reserved != obj.reserved :
            return False
        if self.object_key != obj.object_key :
            return False
        if self.operation != obj.operation :
            return False
        if self.requesting_principal != obj.requesting_principal :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('ServiceContextList service_context=' + repr(self.service_context))
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        lst.append('boolean response_expected=' + repr(self.response_expected))
        lst.append('octet[3] reserved=' + repr(self.reserved))
        lst.append('octet<> object_key=' + repr(self.object_key))
        lst.append('string operation=' + repr(self.operation))
        lst.append('Principal requesting_principal=' + repr(self.requesting_principal))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct RequestHeader_1_1 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/RequestHeader_1_1:1.0'

    corba_id = classmethod(_get_id)

class AddressingDisposition(int):
    """ Typedef IDL:omg.org/GIOP/AddressingDisposition:1.0 """

    def __init__(self, val):
        int.__init__(val)
        CORBA.check('short', val)

    def marshal(self, output):
        CORBA.marshal(output, 'short', self)

    def demarshal(cls, input):
        val = CORBA.demarshal(input, 'short')
        return cls(val)
    demarshal = classmethod(demarshal)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/AddressingDisposition:1.0'

    corba_id = classmethod(_get_id)

# Constant: IDL:omg.org/GIOP/KeyAddr:1.0
KeyAddr = 0

# Constant: IDL:omg.org/GIOP/ProfileAddr:1.0
ProfileAddr = 1

# Constant: IDL:omg.org/GIOP/ReferenceAddr:1.0
ReferenceAddr = 2

class IORAddressingInfo(object):
    """ Struct IDL:omg.org/GIOP/IORAddressingInfo:1.0 """

    class IOR(object):
        """ Struct IDL:omg.org/IOP/IOR:1.0 """

        def __init__(self, type_id, profiles):
            self._settype_id(type_id)
            self._setprofiles(profiles)

        def _settype_id(self, type_id):
            CORBA.check('string', type_id)
            self._type_id = type_id

        def _gettype_id(self):
            return self._type_id

        type_id = property(fset=_settype_id, fget=_gettype_id)

        def _setprofiles(self, profiles):
            _e0 = profiles
            CORBA.check('long', len(_e0))
            for _e1 in _e0 :
                CORBA.check(TaggedProfile, _e1)
            self._profiles = profiles

        def _getprofiles(self):
            return self._profiles

        profiles = property(fset=_setprofiles, fget=_getprofiles)

        def marshal(self, output):
                CORBA.marshal(output, 'string', self.type_id)
                _e0 = self.profiles
                CORBA.marshal(output, 'long', len(_e0))
                for _e1 in _e0 :
                    _e1.marshal(output)

        def demarshal(cls, input):
                type_id = CORBA.demarshal(input, 'string')
                _len0 = CORBA.demarshal(input, 'long')
                _lst0 = []
                for _i0 in xrange(_len0) :
                    _lst0.append(TaggedProfile.demarshal(input))
                profiles = _lst0
                return cls(type_id, profiles)
        demarshal = classmethod(demarshal)

        def __eq__(self, obj):
            if obj == None :
                return False
            if isinstance(obj, type(self)) == False :
                return False
            if self.type_id != obj.type_id :
                return False
            if self.profiles != obj.profiles :
                return False
            return True

        def __repr__(self):
            lst = []
            lst.append('string type_id=' + repr(self.type_id))
            lst.append('TaggedProfile<> profiles=' + repr(self.profiles))
            inner = ',\n'.join(lst)
            inner = '\n'.join(['   ' + line for line in inner.split('\n')])
            return 'struct IOR {\n' + inner + '\n}'

        def _get_id(cls):
            return 'IDL:omg.org/IOP/IOR:1.0'

        corba_id = classmethod(_get_id)

    def __init__(self, selected_profile_index, ior):
        self._setselected_profile_index(selected_profile_index)
        self._setior(ior)

    def _setselected_profile_index(self, selected_profile_index):
        CORBA.check('unsigned_long', selected_profile_index)
        self._selected_profile_index = selected_profile_index

    def _getselected_profile_index(self):
        return self._selected_profile_index

    selected_profile_index = property(fset=_setselected_profile_index, fget=_getselected_profile_index)

    def _setior(self, ior):
        CORBA.check(IOP.IOR, ior)
        self._ior = ior

    def _getior(self):
        return self._ior

    ior = property(fset=_setior, fget=_getior)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.selected_profile_index)
            self.ior.marshal(output)

    def demarshal(cls, input):
            selected_profile_index = CORBA.demarshal(input, 'unsigned_long')
            ior = IOP.IOR.demarshal(input)
            return cls(selected_profile_index, ior)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.selected_profile_index != obj.selected_profile_index :
            return False
        if self.ior != obj.ior :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long selected_profile_index=' + repr(self.selected_profile_index))
        lst.append('IOR ior=' + repr(self.ior))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct IORAddressingInfo {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/IORAddressingInfo:1.0'

    corba_id = classmethod(_get_id)

class TargetAddress(object):
    """ Union IDL:omg.org/GIOP/TargetAddress:1.0 """

    class TaggedProfile(object):
        """ Struct IDL:omg.org/IOP/TaggedProfile:1.0 """

        def __init__(self, tag, profile_data):
            self._settag(tag)
            self._setprofile_data(profile_data)

        def _settag(self, tag):
            CORBA.check(ProfileId, tag)
            self._tag = tag

        def _gettag(self):
            return self._tag

        tag = property(fset=_settag, fget=_gettag)

        def _setprofile_data(self, profile_data):
            _e0 = profile_data
            CORBA.check('long', len(_e0))
            for _e1 in _e0 :
                CORBA.check('octet', ord(_e1))
            self._profile_data = profile_data

        def _getprofile_data(self):
            return self._profile_data

        profile_data = property(fset=_setprofile_data, fget=_getprofile_data)

        def marshal(self, output):
                self.tag.marshal(output)
                _e0 = self.profile_data
                CORBA.marshal(output, 'long', len(_e0))
                for _e1 in _e0 :
                    CORBA.marshal(output, 'octet', ord(_e1))

        def demarshal(cls, input):
                tag = ProfileId.demarshal(input)
                _len0 = CORBA.demarshal(input, 'long')
                _lst0 = []
                for _i0 in xrange(_len0) :
                    _lst0.append(CORBA.demarshal(input, 'octet'))
                _lst0 = ''.join(map(chr, _lst0))
                profile_data = _lst0
                return cls(tag, profile_data)
        demarshal = classmethod(demarshal)

        def __eq__(self, obj):
            if obj == None :
                return False
            if isinstance(obj, type(self)) == False :
                return False
            if self.tag != obj.tag :
                return False
            if self.profile_data != obj.profile_data :
                return False
            return True

        def __repr__(self):
            lst = []
            lst.append('ProfileId tag=' + repr(self.tag))
            lst.append('octet<> profile_data=' + repr(self.profile_data))
            inner = ',\n'.join(lst)
            inner = '\n'.join(['   ' + line for line in inner.split('\n')])
            return 'struct TaggedProfile {\n' + inner + '\n}'

        def _get_id(cls):
            return 'IDL:omg.org/IOP/TaggedProfile:1.0'

        corba_id = classmethod(_get_id)

    def __init__(self, *args, **kwargs):
        if len(args) == 2 :
            _d, _v = args
            CORBA.check(AddressingDisposition, _d)
            if _d == AddressingDisposition(KeyAddr) :
                _e0 = _v
                CORBA.check('long', len(_e0))
                for _e1 in _e0 :
                    CORBA.check('octet', ord(_e1))
            elif _d == AddressingDisposition(ProfileAddr) :
                CORBA.check(IOP.TaggedProfile, _v)
            elif _d == AddressingDisposition(ReferenceAddr) :
                CORBA.check(IORAddressingInfo, _v)
            else :
                raise CORBA.SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA.CORBA_COMPLETED_MAYBE)
            self.__d = _d
            self.__v = _v
        elif 'object_key' in kwargs :
            self._setobject_key(kwargs['object_key'])
        elif 'profile' in kwargs :
            self._setprofile(kwargs['profile'])
        elif 'ior' in kwargs :
            self._setior(kwargs['ior'])
        else :
            raise CORBA.SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA.CORBA_COMPLETED_MAYBE)

    def _get_d(self):
        return self.__d

    _d = property(fget=_get_d)

    def _get_v(self):
        if self.__d == AddressingDisposition(KeyAddr) :
            return self.__v
        elif self.__d == AddressingDisposition(ProfileAddr) :
            return self.__v
        elif self.__d == AddressingDisposition(ReferenceAddr) :
            return self.__v
        else :
            return None

    _v = property(fget=_get_v)

    def _setobject_key(self, object_key):
        _e0 = object_key
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self.__d = AddressingDisposition(KeyAddr)
        self.__v = object_key

    def _getobject_key(self):
        if self.__d == AddressingDisposition(KeyAddr) :
            return self.__v
        return None

    object_key = property(fset=_setobject_key, fget=_getobject_key)

    def _setprofile(self, profile):
        CORBA.check(IOP.TaggedProfile, profile)
        self.__d = AddressingDisposition(ProfileAddr)
        self.__v = profile

    def _getprofile(self):
        if self.__d == AddressingDisposition(ProfileAddr) :
            return self.__v
        return None

    profile = property(fset=_setprofile, fget=_getprofile)

    def _setior(self, ior):
        CORBA.check(IORAddressingInfo, ior)
        self.__d = AddressingDisposition(ReferenceAddr)
        self.__v = ior

    def _getior(self):
        if self.__d == AddressingDisposition(ReferenceAddr) :
            return self.__v
        return None

    ior = property(fset=_setior, fget=_getior)

    def marshal(self, output):
        self._d.marshal(output)
        if self._d == AddressingDisposition(KeyAddr) :
            _e0 = self.__v
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))
        elif self._d == AddressingDisposition(ProfileAddr) :
            self.__v.marshal(output)
        elif self._d == AddressingDisposition(ReferenceAddr) :
            self.__v.marshal(output)
        else :
            raise CORBA.SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA.CORBA_COMPLETED_MAYBE)

    def demarshal(cls, input):
        _d = AddressingDisposition.demarshal(input)
        if _d == AddressingDisposition(KeyAddr) :
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            object_key = _lst0
            return cls(_d, object_key)
        elif _d == AddressingDisposition(ProfileAddr) :
            profile = IOP.TaggedProfile.demarshal(input)
            return cls(_d, profile)
        elif _d == AddressingDisposition(ReferenceAddr) :
            ior = IORAddressingInfo.demarshal(input)
            return cls(_d, ior)
        else :
            raise CORBA.SystemException('IDL:CORBA/MARSHAL:1.0', 9, CORBA.CORBA_COMPLETED_MAYBE)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, TargetAddress) == True :
            if self._d == obj._d :
                return self._v == obj._v
            else :
                return False
        else :
            return False

    def __repr__(self):
        lst = []
        lst.append('_d=' + repr(self._d))
        lst.append('_v=' + repr(self._v))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'union TargetAddress {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/TargetAddress:1.0'

    corba_id = classmethod(_get_id)

class RequestHeader_1_2(object):
    """ Struct IDL:omg.org/GIOP/RequestHeader_1_2:1.0 """

    def __init__(self, request_id, response_flags, reserved, target, operation, service_context):
        self._setrequest_id(request_id)
        self._setresponse_flags(response_flags)
        self._setreserved(reserved)
        self._settarget(target)
        self._setoperation(operation)
        self._setservice_context(service_context)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def _setresponse_flags(self, response_flags):
        CORBA.check('octet', response_flags)
        self._response_flags = response_flags

    def _getresponse_flags(self):
        return self._response_flags

    response_flags = property(fset=_setresponse_flags, fget=_getresponse_flags)

    def _setreserved(self, reserved):
        _e0 = reserved
        if len(_e0) != 3 :
            raise CORBA.SystemException('IDL:CORBA/BAD_PARAM:1.0', 2, CORBA.CORBA_COMPLETED_MAYBE)
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._reserved = reserved

    def _getreserved(self):
        return self._reserved

    reserved = property(fset=_setreserved, fget=_getreserved)

    def _settarget(self, target):
        CORBA.check(TargetAddress, target)
        self._target = target

    def _gettarget(self):
        return self._target

    target = property(fset=_settarget, fget=_gettarget)

    def _setoperation(self, operation):
        CORBA.check('string', operation)
        self._operation = operation

    def _getoperation(self):
        return self._operation

    operation = property(fset=_setoperation, fget=_getoperation)

    def _setservice_context(self, service_context):
        CORBA.check(IOP.ServiceContextList, service_context)
        self._service_context = service_context

    def _getservice_context(self):
        return self._service_context

    service_context = property(fset=_setservice_context, fget=_getservice_context)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.request_id)
            CORBA.marshal(output, 'octet', self.response_flags)
            _e0 = self.reserved
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))
            self.target.marshal(output)
            CORBA.marshal(output, 'string', self.operation)
            self.service_context.marshal(output)

    def demarshal(cls, input):
            request_id = CORBA.demarshal(input, 'unsigned_long')
            response_flags = CORBA.demarshal(input, 'octet')
            _lst0 = []
            for _i0 in xrange(3) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            reserved = _lst0
            target = TargetAddress.demarshal(input)
            operation = CORBA.demarshal(input, 'string')
            service_context = IOP.ServiceContextList.demarshal(input)
            return cls(request_id, response_flags, reserved, target, operation, service_context)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.request_id != obj.request_id :
            return False
        if self.response_flags != obj.response_flags :
            return False
        if self.reserved != obj.reserved :
            return False
        if self.target != obj.target :
            return False
        if self.operation != obj.operation :
            return False
        if self.service_context != obj.service_context :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        lst.append('octet response_flags=' + repr(self.response_flags))
        lst.append('octet[3] reserved=' + repr(self.reserved))
        lst.append('TargetAddress target=' + repr(self.target))
        lst.append('string operation=' + repr(self.operation))
        lst.append('ServiceContextList service_context=' + repr(self.service_context))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct RequestHeader_1_2 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/RequestHeader_1_2:1.0'

    corba_id = classmethod(_get_id)

class RequestHeader_1_3(RequestHeader_1_2):
    """ Typedef IDL:omg.org/GIOP/RequestHeader_1_3:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], RequestHeader_1_2):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(RequestHeader_1_3, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/RequestHeader_1_3:1.0'

    corba_id = classmethod(_get_id)

class ReplyStatusType_1_2(CORBA.Enum):
    """ Enum IDL:omg.org/GIOP/ReplyStatusType_1_2:1.0 """

    _enum_str = dict()
    _enum = dict()

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/ReplyStatusType_1_2:1.0'

    corba_id = classmethod(_get_id)

NO_EXCEPTION = ReplyStatusType_1_2('NO_EXCEPTION', 0)
USER_EXCEPTION = ReplyStatusType_1_2('USER_EXCEPTION', 1)
SYSTEM_EXCEPTION = ReplyStatusType_1_2('SYSTEM_EXCEPTION', 2)
LOCATION_FORWARD = ReplyStatusType_1_2('LOCATION_FORWARD', 3)
LOCATION_FORWARD_PERM = ReplyStatusType_1_2('LOCATION_FORWARD_PERM', 4)
NEEDS_ADDRESSING_MODE = ReplyStatusType_1_2('NEEDS_ADDRESSING_MODE', 5)

class ReplyHeader_1_2(object):
    """ Struct IDL:omg.org/GIOP/ReplyHeader_1_2:1.0 """

    def __init__(self, request_id, reply_status, service_context):
        self._setrequest_id(request_id)
        self._setreply_status(reply_status)
        self._setservice_context(service_context)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def _setreply_status(self, reply_status):
        CORBA.check(ReplyStatusType_1_2, reply_status)
        self._reply_status = reply_status

    def _getreply_status(self):
        return self._reply_status

    reply_status = property(fset=_setreply_status, fget=_getreply_status)

    def _setservice_context(self, service_context):
        CORBA.check(IOP.ServiceContextList, service_context)
        self._service_context = service_context

    def _getservice_context(self):
        return self._service_context

    service_context = property(fset=_setservice_context, fget=_getservice_context)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.request_id)
            self.reply_status.marshal(output)
            self.service_context.marshal(output)

    def demarshal(cls, input):
            request_id = CORBA.demarshal(input, 'unsigned_long')
            reply_status = ReplyStatusType_1_2.demarshal(input)
            service_context = IOP.ServiceContextList.demarshal(input)
            return cls(request_id, reply_status, service_context)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.request_id != obj.request_id :
            return False
        if self.reply_status != obj.reply_status :
            return False
        if self.service_context != obj.service_context :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        lst.append('ReplyStatusType_1_2 reply_status=' + repr(self.reply_status))
        lst.append('ServiceContextList service_context=' + repr(self.service_context))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct ReplyHeader_1_2 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/ReplyHeader_1_2:1.0'

    corba_id = classmethod(_get_id)

class ReplyHeader_1_3(ReplyHeader_1_2):
    """ Typedef IDL:omg.org/GIOP/ReplyHeader_1_3:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], ReplyHeader_1_2):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(ReplyHeader_1_3, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/ReplyHeader_1_3:1.0'

    corba_id = classmethod(_get_id)

class SystemExceptionReplyBody(object):
    """ Struct IDL:omg.org/GIOP/SystemExceptionReplyBody:1.0 """

    def __init__(self, exception_id, minor_code_value, completion_status):
        self._setexception_id(exception_id)
        self._setminor_code_value(minor_code_value)
        self._setcompletion_status(completion_status)

    def _setexception_id(self, exception_id):
        CORBA.check('string', exception_id)
        self._exception_id = exception_id

    def _getexception_id(self):
        return self._exception_id

    exception_id = property(fset=_setexception_id, fget=_getexception_id)

    def _setminor_code_value(self, minor_code_value):
        CORBA.check('unsigned_long', minor_code_value)
        self._minor_code_value = minor_code_value

    def _getminor_code_value(self):
        return self._minor_code_value

    minor_code_value = property(fset=_setminor_code_value, fget=_getminor_code_value)

    def _setcompletion_status(self, completion_status):
        CORBA.check('unsigned_long', completion_status)
        self._completion_status = completion_status

    def _getcompletion_status(self):
        return self._completion_status

    completion_status = property(fset=_setcompletion_status, fget=_getcompletion_status)

    def marshal(self, output):
            CORBA.marshal(output, 'string', self.exception_id)
            CORBA.marshal(output, 'unsigned_long', self.minor_code_value)
            CORBA.marshal(output, 'unsigned_long', self.completion_status)

    def demarshal(cls, input):
            exception_id = CORBA.demarshal(input, 'string')
            minor_code_value = CORBA.demarshal(input, 'unsigned_long')
            completion_status = CORBA.demarshal(input, 'unsigned_long')
            return cls(exception_id, minor_code_value, completion_status)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.exception_id != obj.exception_id :
            return False
        if self.minor_code_value != obj.minor_code_value :
            return False
        if self.completion_status != obj.completion_status :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('string exception_id=' + repr(self.exception_id))
        lst.append('unsigned_long minor_code_value=' + repr(self.minor_code_value))
        lst.append('unsigned_long completion_status=' + repr(self.completion_status))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct SystemExceptionReplyBody {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/SystemExceptionReplyBody:1.0'

    corba_id = classmethod(_get_id)

class CancelRequestHeader(object):
    """ Struct IDL:omg.org/GIOP/CancelRequestHeader:1.0 """

    def __init__(self, request_id):
        self._setrequest_id(request_id)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.request_id)

    def demarshal(cls, input):
            request_id = CORBA.demarshal(input, 'unsigned_long')
            return cls(request_id)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.request_id != obj.request_id :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct CancelRequestHeader {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/CancelRequestHeader:1.0'

    corba_id = classmethod(_get_id)

class LocateRequestHeader_1_0(object):
    """ Struct IDL:omg.org/GIOP/LocateRequestHeader_1_0:1.0 """

    def __init__(self, request_id, object_key):
        self._setrequest_id(request_id)
        self._setobject_key(object_key)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def _setobject_key(self, object_key):
        _e0 = object_key
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._object_key = object_key

    def _getobject_key(self):
        return self._object_key

    object_key = property(fset=_setobject_key, fget=_getobject_key)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.request_id)
            _e0 = self.object_key
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))

    def demarshal(cls, input):
            request_id = CORBA.demarshal(input, 'unsigned_long')
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            object_key = _lst0
            return cls(request_id, object_key)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.request_id != obj.request_id :
            return False
        if self.object_key != obj.object_key :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        lst.append('octet<> object_key=' + repr(self.object_key))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct LocateRequestHeader_1_0 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/LocateRequestHeader_1_0:1.0'

    corba_id = classmethod(_get_id)

class LocateRequestHeader_1_1(LocateRequestHeader_1_0):
    """ Typedef IDL:omg.org/GIOP/LocateRequestHeader_1_1:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], LocateRequestHeader_1_0):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(LocateRequestHeader_1_1, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/LocateRequestHeader_1_1:1.0'

    corba_id = classmethod(_get_id)

class LocateRequestHeader_1_2(object):
    """ Struct IDL:omg.org/GIOP/LocateRequestHeader_1_2:1.0 """

    def __init__(self, request_id, target):
        self._setrequest_id(request_id)
        self._settarget(target)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def _settarget(self, target):
        CORBA.check(TargetAddress, target)
        self._target = target

    def _gettarget(self):
        return self._target

    target = property(fset=_settarget, fget=_gettarget)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.request_id)
            self.target.marshal(output)

    def demarshal(cls, input):
            request_id = CORBA.demarshal(input, 'unsigned_long')
            target = TargetAddress.demarshal(input)
            return cls(request_id, target)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.request_id != obj.request_id :
            return False
        if self.target != obj.target :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        lst.append('TargetAddress target=' + repr(self.target))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct LocateRequestHeader_1_2 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/LocateRequestHeader_1_2:1.0'

    corba_id = classmethod(_get_id)

class LocateRequestHeader_1_3(LocateRequestHeader_1_2):
    """ Typedef IDL:omg.org/GIOP/LocateRequestHeader_1_3:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], LocateRequestHeader_1_2):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(LocateRequestHeader_1_3, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/LocateRequestHeader_1_3:1.0'

    corba_id = classmethod(_get_id)

class LocateStatusType_1_2(CORBA.Enum):
    """ Enum IDL:omg.org/GIOP/LocateStatusType_1_2:1.0 """

    _enum_str = dict()
    _enum = dict()

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/LocateStatusType_1_2:1.0'

    corba_id = classmethod(_get_id)

UNKNOWN_OBJECT = LocateStatusType_1_2('UNKNOWN_OBJECT', 0)
OBJECT_HERE = LocateStatusType_1_2('OBJECT_HERE', 1)
OBJECT_FORWARD = LocateStatusType_1_2('OBJECT_FORWARD', 2)
OBJECT_FORWARD_PERM = LocateStatusType_1_2('OBJECT_FORWARD_PERM', 3)
LOC_SYSTEM_EXCEPTION = LocateStatusType_1_2('LOC_SYSTEM_EXCEPTION', 4)
LOC_NEEDS_ADDRESSING_MODE = LocateStatusType_1_2('LOC_NEEDS_ADDRESSING_MODE', 5)

class LocateReplyHeader_1_2(object):
    """ Struct IDL:omg.org/GIOP/LocateReplyHeader_1_2:1.0 """

    def __init__(self, request_id, locate_status):
        self._setrequest_id(request_id)
        self._setlocate_status(locate_status)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def _setlocate_status(self, locate_status):
        CORBA.check(LocateStatusType_1_2, locate_status)
        self._locate_status = locate_status

    def _getlocate_status(self):
        return self._locate_status

    locate_status = property(fset=_setlocate_status, fget=_getlocate_status)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.request_id)
            self.locate_status.marshal(output)

    def demarshal(cls, input):
            request_id = CORBA.demarshal(input, 'unsigned_long')
            locate_status = LocateStatusType_1_2.demarshal(input)
            return cls(request_id, locate_status)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.request_id != obj.request_id :
            return False
        if self.locate_status != obj.locate_status :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        lst.append('LocateStatusType_1_2 locate_status=' + repr(self.locate_status))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct LocateReplyHeader_1_2 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/LocateReplyHeader_1_2:1.0'

    corba_id = classmethod(_get_id)

class LocateReplyHeader_1_3(LocateReplyHeader_1_2):
    """ Typedef IDL:omg.org/GIOP/LocateReplyHeader_1_3:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], LocateReplyHeader_1_2):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(LocateReplyHeader_1_3, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/LocateReplyHeader_1_3:1.0'

    corba_id = classmethod(_get_id)

class FragmentHeader_1_2(object):
    """ Struct IDL:omg.org/GIOP/FragmentHeader_1_2:1.0 """

    def __init__(self, request_id):
        self._setrequest_id(request_id)

    def _setrequest_id(self, request_id):
        CORBA.check('unsigned_long', request_id)
        self._request_id = request_id

    def _getrequest_id(self):
        return self._request_id

    request_id = property(fset=_setrequest_id, fget=_getrequest_id)

    def marshal(self, output):
            CORBA.marshal(output, 'unsigned_long', self.request_id)

    def demarshal(cls, input):
            request_id = CORBA.demarshal(input, 'unsigned_long')
            return cls(request_id)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.request_id != obj.request_id :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('unsigned_long request_id=' + repr(self.request_id))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct FragmentHeader_1_2 {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/FragmentHeader_1_2:1.0'

    corba_id = classmethod(_get_id)

class FragmentHeader_1_3(FragmentHeader_1_2):
    """ Typedef IDL:omg.org/GIOP/FragmentHeader_1_3:1.0 """

    def __init__(self, *args, **kw):
        if len(args) == 1 and isinstance(args[0], FragmentHeader_1_2):
            self.__dict__ = dict(args[0].__dict__)
        else:
            super(FragmentHeader_1_3, self).__init__(*args, **kw)

    def _get_id(cls):
        return 'IDL:omg.org/GIOP/FragmentHeader_1_3:1.0'

    corba_id = classmethod(_get_id)




#   This file was generated (by idl2py.pl). DO NOT modify it.
# From file : iop.idl, 5190 octets, Fri Dec 27 20:11:20 2002

import PyIDL as CORBA


""" Module IDL:omg.org/IOP:1.0 """

class ProfileId(long):
    """ Typedef IDL:omg.org/IOP/ProfileId:1.0 """

    def __init__(self, val):
        int.__init__(val)
        CORBA.check('unsigned_long', val)

    def marshal(self, output):
        CORBA.marshal(output, 'unsigned_long', self)

    def demarshal(cls, input):
        val = CORBA.demarshal(input, 'unsigned_long')
        return cls(val)
    demarshal = classmethod(demarshal)

    def _get_id(cls):
        return 'IDL:omg.org/IOP/ProfileId:1.0'

    corba_id = classmethod(_get_id)

# Constant: IDL:omg.org/IOP/TAG_INTERNET_IOP:1.0
TAG_INTERNET_IOP = 0L

# Constant: IDL:omg.org/IOP/TAG_MULTIPLE_COMPONENTS:1.0
TAG_MULTIPLE_COMPONENTS = 1L

# Constant: IDL:omg.org/IOP/TAG_SCCP_IOP:1.0
TAG_SCCP_IOP = 2L

class TaggedProfile(object):
    """ Struct IDL:omg.org/IOP/TaggedProfile:1.0 """

    def __init__(self, tag, profile_data):
        self._settag(tag)
        self._setprofile_data(profile_data)

    def _settag(self, tag):
        CORBA.check(ProfileId, tag)
        self._tag = tag

    def _gettag(self):
        return self._tag

    tag = property(fset=_settag, fget=_gettag)

    def _setprofile_data(self, profile_data):
        _e0 = profile_data
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._profile_data = profile_data

    def _getprofile_data(self):
        return self._profile_data

    profile_data = property(fset=_setprofile_data, fget=_getprofile_data)

    def marshal(self, output):
            self.tag.marshal(output)
            _e0 = self.profile_data
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))

    def demarshal(cls, input):
            tag = ProfileId.demarshal(input)
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            profile_data = _lst0
            return cls(tag, profile_data)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.tag != obj.tag :
            return False
        if self.profile_data != obj.profile_data :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('ProfileId tag=' + repr(self.tag))
        lst.append('octet<> profile_data=' + repr(self.profile_data))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct TaggedProfile {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/IOP/TaggedProfile:1.0'

    corba_id = classmethod(_get_id)

class IOR(object):
    """ Struct IDL:omg.org/IOP/IOR:1.0 """

    def __init__(self, type_id, profiles):
        self._settype_id(type_id)
        self._setprofiles(profiles)

    def _settype_id(self, type_id):
        CORBA.check('string', type_id)
        self._type_id = type_id

    def _gettype_id(self):
        return self._type_id

    type_id = property(fset=_settype_id, fget=_gettype_id)

    def _setprofiles(self, profiles):
        _e0 = profiles
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check(TaggedProfile, _e1)
        self._profiles = profiles

    def _getprofiles(self):
        return self._profiles

    profiles = property(fset=_setprofiles, fget=_getprofiles)

    def marshal(self, output):
            CORBA.marshal(output, 'string', self.type_id)
            _e0 = self.profiles
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                _e1.marshal(output)

    def demarshal(cls, input):
            type_id = CORBA.demarshal(input, 'string')
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(TaggedProfile.demarshal(input))
            profiles = _lst0
            return cls(type_id, profiles)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.type_id != obj.type_id :
            return False
        if self.profiles != obj.profiles :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('string type_id=' + repr(self.type_id))
        lst.append('TaggedProfile<> profiles=' + repr(self.profiles))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct IOR {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/IOP/IOR:1.0'

    corba_id = classmethod(_get_id)

class ComponentId(long):
    """ Typedef IDL:omg.org/IOP/ComponentId:1.0 """

    def __init__(self, val):
        int.__init__(val)
        CORBA.check('unsigned_long', val)

    def marshal(self, output):
        CORBA.marshal(output, 'unsigned_long', self)

    def demarshal(cls, input):
        val = CORBA.demarshal(input, 'unsigned_long')
        return cls(val)
    demarshal = classmethod(demarshal)

    def _get_id(cls):
        return 'IDL:omg.org/IOP/ComponentId:1.0'

    corba_id = classmethod(_get_id)

class TaggedComponent(object):
    """ Struct IDL:omg.org/IOP/TaggedComponent:1.0 """

    def __init__(self, tag, component_data):
        self._settag(tag)
        self._setcomponent_data(component_data)

    def _settag(self, tag):
        CORBA.check(ComponentId, tag)
        self._tag = tag

    def _gettag(self):
        return self._tag

    tag = property(fset=_settag, fget=_gettag)

    def _setcomponent_data(self, component_data):
        _e0 = component_data
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._component_data = component_data

    def _getcomponent_data(self):
        return self._component_data

    component_data = property(fset=_setcomponent_data, fget=_getcomponent_data)

    def marshal(self, output):
            self.tag.marshal(output)
            _e0 = self.component_data
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))

    def demarshal(cls, input):
            tag = ComponentId.demarshal(input)
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            component_data = _lst0
            return cls(tag, component_data)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.tag != obj.tag :
            return False
        if self.component_data != obj.component_data :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('ComponentId tag=' + repr(self.tag))
        lst.append('octet<> component_data=' + repr(self.component_data))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct TaggedComponent {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/IOP/TaggedComponent:1.0'

    corba_id = classmethod(_get_id)

class MultipleComponentProfile(list):
    """ Typedef IDL:omg.org/IOP/MultipleComponentProfile:1.0 """

    def __init__(self, *params):
        list.__init__(self, *params)
        _e0 = list(*params)
        for _e1 in _e0 :
            CORBA.check(TaggedComponent, _e1)

    def marshal(self, output):
        _e0 = self
        CORBA.marshal(output, 'long', len(_e0))
        for _e1 in _e0 :
            _e1.marshal(output)

    def demarshal(cls, input):
        _len0 = CORBA.demarshal(input, 'long')
        _lst0 = []
        for _i0 in xrange(_len0) :
            _lst0.append(TaggedComponent.demarshal(input))
        return cls(_lst0)
    demarshal = classmethod(demarshal)

    def _get_id(cls):
        return 'IDL:omg.org/IOP/MultipleComponentProfile:1.0'

    corba_id = classmethod(_get_id)

# Constant: IDL:omg.org/IOP/TAG_ORB_TYPE:1.0
TAG_ORB_TYPE = 0L

# Constant: IDL:omg.org/IOP/TAG_CODE_SETS:1.0
TAG_CODE_SETS = 1L

# Constant: IDL:omg.org/IOP/TAG_POLICIES:1.0
TAG_POLICIES = 2L

# Constant: IDL:omg.org/IOP/TAG_ALTERNATE_IIOP_ADDRESS:1.0
TAG_ALTERNATE_IIOP_ADDRESS = 3L

# Constant: IDL:omg.org/IOP/TAG_ASSOCIATION_OPTIONS:1.0
TAG_ASSOCIATION_OPTIONS = 13L

# Constant: IDL:omg.org/IOP/TAG_SEC_NAME:1.0
TAG_SEC_NAME = 14L

# Constant: IDL:omg.org/IOP/TAG_SPKM_1_SEC_MECH:1.0
TAG_SPKM_1_SEC_MECH = 15L

# Constant: IDL:omg.org/IOP/TAG_SPKM_2_SEC_MECH:1.0
TAG_SPKM_2_SEC_MECH = 16L

# Constant: IDL:omg.org/IOP/TAG_KerberosV5_SEC_MECH:1.0
TAG_KerberosV5_SEC_MECH = 17L

# Constant: IDL:omg.org/IOP/TAG_CSI_ECMA_Secret_SEC_MECH:1.0
TAG_CSI_ECMA_Secret_SEC_MECH = 18L

# Constant: IDL:omg.org/IOP/TAG_CSI_ECMA_Hybrid_SEC_MECH:1.0
TAG_CSI_ECMA_Hybrid_SEC_MECH = 19L

# Constant: IDL:omg.org/IOP/TAG_SSL_SEC_TRANS:1.0
TAG_SSL_SEC_TRANS = 20L

# Constant: IDL:omg.org/IOP/TAG_CSI_ECMA_Public_SEC_MECH:1.0
TAG_CSI_ECMA_Public_SEC_MECH = 21L

# Constant: IDL:omg.org/IOP/TAG_GENERIC_SEC_MECH:1.0
TAG_GENERIC_SEC_MECH = 22L

# Constant: IDL:omg.org/IOP/TAG_FIREWALL_TRANS:1.0
TAG_FIREWALL_TRANS = 23L

# Constant: IDL:omg.org/IOP/TAG_SCCP_CONTACT_INFO:1.0
TAG_SCCP_CONTACT_INFO = 24L

# Constant: IDL:omg.org/IOP/TAG_JAVA_CODEBASE:1.0
TAG_JAVA_CODEBASE = 25L

# Constant: IDL:omg.org/IOP/TAG_TRANSACTION_POLICY:1.0
TAG_TRANSACTION_POLICY = 26L

# Constant: IDL:omg.org/IOP/TAG_MESSAGE_ROUTER:1.0
TAG_MESSAGE_ROUTER = 30L

# Constant: IDL:omg.org/IOP/TAG_OTS_POLICY:1.0
TAG_OTS_POLICY = 31L

# Constant: IDL:omg.org/IOP/TAG_INV_POLICY:1.0
TAG_INV_POLICY = 32L

# Constant: IDL:omg.org/IOP/TAG_CSI_SEC_MECH_LIST:1.0
TAG_CSI_SEC_MECH_LIST = 33L

# Constant: IDL:omg.org/IOP/TAG_NULL_TAG:1.0
TAG_NULL_TAG = 34L

# Constant: IDL:omg.org/IOP/TAG_SECIOP_SEC_TRANS:1.0
TAG_SECIOP_SEC_TRANS = 35L

# Constant: IDL:omg.org/IOP/TAG_TLS_SEC_TRANS:1.0
TAG_TLS_SEC_TRANS = 36L

# Constant: IDL:omg.org/IOP/TAG_ACTIVITY_POLICY:1.0
TAG_ACTIVITY_POLICY = 37L

# Constant: IDL:omg.org/IOP/TAG_COMPLETE_OBJECT_KEY:1.0
TAG_COMPLETE_OBJECT_KEY = 5L

# Constant: IDL:omg.org/IOP/TAG_ENDPOINT_ID_POSITION:1.0
TAG_ENDPOINT_ID_POSITION = 6L

# Constant: IDL:omg.org/IOP/TAG_LOCATION_POLICY:1.0
TAG_LOCATION_POLICY = 12L

# Constant: IDL:omg.org/IOP/TAG_DCE_STRING_BINDING:1.0
TAG_DCE_STRING_BINDING = 100L

# Constant: IDL:omg.org/IOP/TAG_DCE_BINDING_NAME:1.0
TAG_DCE_BINDING_NAME = 101L

# Constant: IDL:omg.org/IOP/TAG_DCE_NO_PIPES:1.0
TAG_DCE_NO_PIPES = 102L

# Constant: IDL:omg.org/IOP/TAG_DCE_SEC_MECH:1.0
TAG_DCE_SEC_MECH = 103L

# Constant: IDL:omg.org/IOP/TAG_INET_SEC_TRANS:1.0
TAG_INET_SEC_TRANS = 123L

class ServiceId(long):
    """ Typedef IDL:omg.org/IOP/ServiceId:1.0 """

    def __init__(self, val):
        int.__init__(val)
        CORBA.check('unsigned_long', val)

    def marshal(self, output):
        CORBA.marshal(output, 'unsigned_long', self)

    def demarshal(cls, input):
        val = CORBA.demarshal(input, 'unsigned_long')
        return cls(val)
    demarshal = classmethod(demarshal)

    def _get_id(cls):
        return 'IDL:omg.org/IOP/ServiceId:1.0'

    corba_id = classmethod(_get_id)

class ServiceContext(object):
    """ Struct IDL:omg.org/IOP/ServiceContext:1.0 """

    def __init__(self, context_id, context_data):
        self._setcontext_id(context_id)
        self._setcontext_data(context_data)

    def _setcontext_id(self, context_id):
        CORBA.check(ServiceId, context_id)
        self._context_id = context_id

    def _getcontext_id(self):
        return self._context_id

    context_id = property(fset=_setcontext_id, fget=_getcontext_id)

    def _setcontext_data(self, context_data):
        _e0 = context_data
        CORBA.check('long', len(_e0))
        for _e1 in _e0 :
            CORBA.check('octet', ord(_e1))
        self._context_data = context_data

    def _getcontext_data(self):
        return self._context_data

    context_data = property(fset=_setcontext_data, fget=_getcontext_data)

    def marshal(self, output):
            self.context_id.marshal(output)
            _e0 = self.context_data
            CORBA.marshal(output, 'long', len(_e0))
            for _e1 in _e0 :
                CORBA.marshal(output, 'octet', ord(_e1))

    def demarshal(cls, input):
            context_id = ServiceId.demarshal(input)
            _len0 = CORBA.demarshal(input, 'long')
            _lst0 = []
            for _i0 in xrange(_len0) :
                _lst0.append(CORBA.demarshal(input, 'octet'))
            _lst0 = ''.join(map(chr, _lst0))
            context_data = _lst0
            return cls(context_id, context_data)
    demarshal = classmethod(demarshal)

    def __eq__(self, obj):
        if obj == None :
            return False
        if isinstance(obj, type(self)) == False :
            return False
        if self.context_id != obj.context_id :
            return False
        if self.context_data != obj.context_data :
            return False
        return True

    def __repr__(self):
        lst = []
        lst.append('ServiceId context_id=' + repr(self.context_id))
        lst.append('octet<> context_data=' + repr(self.context_data))
        inner = ',\n'.join(lst)
        inner = '\n'.join(['   ' + line for line in inner.split('\n')])
        return 'struct ServiceContext {\n' + inner + '\n}'

    def _get_id(cls):
        return 'IDL:omg.org/IOP/ServiceContext:1.0'

    corba_id = classmethod(_get_id)

class ServiceContextList(list):
    """ Typedef IDL:omg.org/IOP/ServiceContextList:1.0 """

    def __init__(self, *params):
        list.__init__(self, *params)
        _e0 = list(*params)
        for _e1 in _e0 :
            CORBA.check(ServiceContext, _e1)

    def marshal(self, output):
        _e0 = self
        CORBA.marshal(output, 'long', len(_e0))
        for _e1 in _e0 :
            _e1.marshal(output)

    def demarshal(cls, input):
        _len0 = CORBA.demarshal(input, 'long')
        _lst0 = []
        for _i0 in xrange(_len0) :
            _lst0.append(ServiceContext.demarshal(input))
        return cls(_lst0)
    demarshal = classmethod(demarshal)

    def _get_id(cls):
        return 'IDL:omg.org/IOP/ServiceContextList:1.0'

    corba_id = classmethod(_get_id)

# Constant: IDL:omg.org/IOP/TransactionService:1.0
TransactionService = 0L

# Constant: IDL:omg.org/IOP/CodeSets:1.0
CodeSets = 1L

# Constant: IDL:omg.org/IOP/ChainBypassCheck:1.0
ChainBypassCheck = 2L

# Constant: IDL:omg.org/IOP/ChainBypassInfo:1.0
ChainBypassInfo = 3L

# Constant: IDL:omg.org/IOP/LogicalThreadId:1.0
LogicalThreadId = 4L

# Constant: IDL:omg.org/IOP/BI_DIR_IIOP:1.0
BI_DIR_IIOP = 5L

# Constant: IDL:omg.org/IOP/SendingContextRunTime:1.0
SendingContextRunTime = 6L

# Constant: IDL:omg.org/IOP/INVOCATION_POLICIES:1.0
INVOCATION_POLICIES = 7L

# Constant: IDL:omg.org/IOP/FORWARDED_IDENTITY:1.0
FORWARDED_IDENTITY = 8L

# Constant: IDL:omg.org/IOP/UnknownExceptionInfo:1.0
UnknownExceptionInfo = 9L

# Constant: IDL:omg.org/IOP/RTCorbaPriority:1.0
RTCorbaPriority = 10L

# Constant: IDL:omg.org/IOP/RTCorbaPriorityRange:1.0
RTCorbaPriorityRange = 11L

# Constant: IDL:omg.org/IOP/FT_GROUP_VERSION:1.0
FT_GROUP_VERSION = 12L

# Constant: IDL:omg.org/IOP/FT_REQUEST:1.0
FT_REQUEST = 13L

# Constant: IDL:omg.org/IOP/ExceptionDetailMessage:1.0
ExceptionDetailMessage = 14L

# Constant: IDL:omg.org/IOP/SecurityAttributeService:1.0
SecurityAttributeService = 15L

# Constant: IDL:omg.org/IOP/ActivityService:1.0
ActivityService = 16L




#!/usr/bin/env python -w

from Tkinter import *
from ScrolledText import *
import socket

from _Calc import *

class Top:

	def __init__(self, root, calc):
		self._root = root
		self._calc = calc
		# Default settings.
		self._var1_add = IntVar(0)
		self._var2_add = IntVar(0)
		self._var1_sub = IntVar(0)
		self._var2_sub = IntVar(0)
		self._var1_mul = IntVar(0)
		self._var2_mul = IntVar(0)
		self._var1_div = IntVar(0)
		self._var2_div = IntVar(0)

		root.title("GIOP - Tk/Client")

		fr_res = Frame(root,
		)
		fr_res.pack(
		)
		#~ self._text = Scrolled(fr_res,
			#~ "ROText",
			#~ scrollbars='osoe',
		self._text = ScrolledText(fr_res,
			height=12,
			width=32,
		)
		self._text.pack(
		)

		fr_add = Frame(root,
		)
		fr_add.pack(
		)
		b_add = Button(fr_add,
				text="Add",
				padx=10,
				command=self.OnAdd,
		)
		b_add.pack(
				side=LEFT,
		)
		e1_add = Entry(fr_add,
				width=10,
				textvariable=self._var1_add,
		)
		e1_add.pack(
				side=LEFT,
		)
		e2_add = Entry(fr_add,
				width=10,
				textvariable=self._var2_add,
		)
		e2_add.pack(
				side=LEFT,
		)
		
		fr_sub = Frame(root,
		)
		fr_sub.pack(
		)
		b_sub = Button(fr_sub,
				text="Sub",
				padx=10,
				command=self.OnSub,
		)
		b_sub.pack(
				side=LEFT,
		)
		e1_sub = Entry(fr_sub,
				width=10,
				textvariable=self._var1_sub,
		)
		e1_sub.pack(
				side=LEFT,
		)
		e2_sub = Entry(fr_sub,
				width=10,
				textvariable=self._var2_sub,
		)
		e2_sub.pack(
				side=LEFT,
		)
		
		fr_mul = Frame(root,
		)
		fr_mul.pack(
		)
		b_mul = Button(fr_mul,
				text="Mul",
				padx=10,
				command=self.OnMul,
		)
		b_mul.pack(
				side=LEFT,
		)
		e1_mul = Entry(fr_mul,
				width=10,
				textvariable=self._var1_mul,
		)
		e1_mul.pack(
				side=LEFT,
		)
		e2_mul = Entry(fr_mul,
				width=10,
				textvariable=self._var2_mul,
		)
		e2_mul.pack(
				side=LEFT,
		)
		
		fr_div = Frame(root,
		)
		fr_div.pack(
		)
		b_div = Button(fr_div,
				text="Div",
				padx=10,
				command=self.OnDiv,
		)
		b_div.pack(
				side=LEFT,
		)
		e1_div = Entry(fr_div,
				width=10,
				textvariable=self._var1_div,
		)
		e1_div.pack(
				side=LEFT,
		)
		e2_div = Entry(fr_div,
				width=10,
				textvariable=self._var2_div,
		)
		e2_div.pack(
				side=LEFT,
		)		

		# Cntl-C stops the demo.
		root.bind('<Control-c>', lambda x: sys.exit(0))

	def OnAdd(self):
		try:
			ret = self._calc.Add(self._var1_add.get(), self._var2_add.get())
			msg = "%d\n" % ret
			self._text.insert('end', msg)
		except Exception, e:
			self._text.insert('end', e.__str__())

	def OnSub(self):
		try:
			ret = self._calc.Sub(self._var1_sub.get(), self._var2_sub.get())
			msg = "%d\n" % ret
			self._text.insert('end', msg)
		except Exception, e:
			self._text.insert('end', e.__str__())

	def OnMul(self):
		try:
			ret = self._calc.Mul(self._var1_mul.get(), self._var2_mul.get())
			msg = "%d\n" % ret
			self._text.insert('end', msg)
		except Exception, e:
			self._text.insert('end', e.__str__())

	def OnDiv(self):
		try:
			ret = self._calc.Div(self._var1_div.get(), self._var2_div.get())
			msg = "%d\n" % ret
			self._text.insert('end', msg)
		except Calc.DivisionByZero, e:
			msg = "%s\n" % e.__str__()
			self._text.insert('end', msg)
#		except Exception, e:
#			self._text.insert('end', e.__str__())


sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
sock.connect(('localhost', 12345))
calc = Calc(sock)
root = Tk()
top = Top(root, calc)
root.mainloop()



import logging
import socket

import PyIDL as CORBA
import PyIDL.cdr as CDR
import PyIDL.iop as IOP
import PyIDL.giop as GIOP

_LOGGER = logging.getLogger('PyIDL')

_GIOP_HEADER_LENGTH = 12

_request_id = 0

def _getRequestId():
    global _request_id
    _request_id += 1
    return _request_id

def _sendall(sock, data): # Method sendall exists for real sockets but not for simulated ones..
    pos = 0
    remaining = len(data)
    while remaining > 0:
        sent = sock.send(data[pos:])
        if sent == 0:
            raise socket.error("send returned 0 - socket closed")
        pos += sent
        remaining -= sent

def _recvall(sock, requiredSize):
    data = ''
    while len(data) < requiredSize:
        part = sock.recv(requiredSize - len(data))
        if len(part) == 0:
            raise socket.error("recv returned 0 - socket closed")
        data += part
    return data

def RequestOneWay(sock, request_header, request_body):
    request_header.request_id = _getRequestId()
    request = CDR.OutputBuffer()
    request_header.marshal(request)
    request.write(request_body.getvalue())
    msg = CDR.OutputBuffer()
    GIOP.MessageHeader_1_1(
            magic='GIOP',
            GIOP_version=GIOP.Version(major=1, minor=2),
            flags=0x01,         # flags : little endian
            message_type=0,     # Request
            message_size=len(request.getvalue())
    ).marshal(msg)
    msg.write(request.getvalue())
    request.close()
    _sendall(sock, msg.getvalue())
    msg.close()

def RequestReply(sock, request_header, request_body):
    request_header.request_id = _getRequestId()
    request = CDR.OutputBuffer()
    request_header.marshal(request)
    request.write(request_body.getvalue())
    msg = CDR.OutputBuffer()
    GIOP.MessageHeader_1_1(
            magic='GIOP',
            GIOP_version=GIOP.Version(major=1, minor=2),
            flags=0x01,         # flags : little endian
            message_type=0,     # Request
            message_size=len(request.getvalue())
    ).marshal(msg)
    msg.write(request.getvalue())
    request.close()
    _sendall(sock, msg.getvalue())
    msg.close()
    while True:
        _header = _recvall(sock, _GIOP_HEADER_LENGTH)
        header = CDR.InputBuffer(_header)
        magic = ''
        magic += CORBA.demarshal(header, 'char')
        magic += CORBA.demarshal(header, 'char')
        magic += CORBA.demarshal(header, 'char')
        magic += CORBA.demarshal(header, 'char')
        GIOP_version = GIOP.Version.demarshal(header)
        flags = CORBA.demarshal(header, 'octet')
        endian = flags & 0x01
        header.endian = endian      # now, endian is known
        message_type = CORBA.demarshal(header, 'octet')
        message_size = CORBA.demarshal(header, 'unsigned_long')

        if magic == 'GIOP' and GIOP_version.major == 1 and GIOP_version.minor == 2 and message_type == 1:
            _reply = _recvall(sock, message_size)
            reply = CDR.InputBuffer(_reply, endian)
            reply_header = GIOP.ReplyHeader_1_2.demarshal(reply)
            if request_header.request_id == reply_header.request_id:
                _LOGGER.info("reply id %d", reply_header.request_id)
                return (reply_header.reply_status, reply_header.service_context, reply)
            elif request_header.request_id > reply_header.request_id:
                _LOGGER.warning("bad request id %d (wanted %d).", reply_header.request_id, request_header.request_id)
            else:
                _LOGGER.error("bad request id %d (wanted %d).", reply_header.request_id, request_header.request_id)
                raise CORBA.SystemException('IDL:CORBA/INTERNAL:1.0', 8, CORBA.CORBA_COMPLETED_MAYBE)
        else:
            _LOGGER.error("bad header")
            raise CORBA.SystemException('IDL:CORBA/INTERNAL:1.0', 8, CORBA.CORBA_COMPLETED_MAYBE)


class Servant(object):
    def __init__(self):
        self.itf = dict()

    def Register(self, key, value):
        self.itf[key] = value

    def Servant(self, request):
        if len(request) < _GIOP_HEADER_LENGTH:
            _LOGGER.debug("header incomplete")
            return None, request

        def checkHeaderField(name, got, expected):
            if got != expected:
                _LOGGER.error("bad header field: %s got=%s expected=%s", name, got, expected)
                raise CORBA.SystemException('IDL:CORBA/INTERNAL:1.0', 8, CORBA.CORBA_COMPLETED_MAYBE)

        input_buffer = CDR.InputBuffer(request)
        magic = ''
        magic += CORBA.demarshal(input_buffer, 'char')
        magic += CORBA.demarshal(input_buffer, 'char')
        magic += CORBA.demarshal(input_buffer, 'char')
        magic += CORBA.demarshal(input_buffer, 'char')
        checkHeaderField("magic", magic, 'GIOP')

        GIOP_version = GIOP.Version.demarshal(input_buffer)
        checkHeaderField("major version", GIOP_version.major, 1)
        checkHeaderField("minor version", GIOP_version.minor, 2)
        flags = CORBA.demarshal(input_buffer, 'octet')
        endian = flags & 0x01
        input_buffer.endian = endian     # now, endian is known
        message_type = CORBA.demarshal(input_buffer, 'octet')
        message_size = CORBA.demarshal(input_buffer, 'unsigned_long')

        message_data = input_buffer.read(message_size)
        if len(message_data) < message_size:
            _LOGGER.debug("message incomplete")
            return None, request

        # From now on consume the data..
        message = CDR.InputBuffer(message_data)
        message.endian = endian
        remaining_data = input_buffer.read()

        if message_type != 0:
            _LOGGER.error("unexpected message type %s (expected 0)", message_type)
            return None, remaining_data

        request_header = GIOP.RequestHeader_1_2.demarshal(message)
        interface = request_header.target._v
        if self.itf.has_key(interface) == False:
            _LOGGER.warning("unknown interface '%s'.", interface)
            reply_status = GIOP.SYSTEM_EXCEPTION
            reply_body = CDR.OutputBuffer()
            CORBA.marshal(reply_body, 'string', 'IDL:CORBA/NO_IMPLEMENT:1.0')
            CORBA.marshal(reply_body, 'unsigned_long', 11)
            CORBA.marshal(reply_body, 'unsigned_long', 1)   # COMPLETED_NO
        else:
            classname = self.itf[interface]
            op = request_header.operation
            if not hasattr(classname, op):
                _LOGGER.error("unknown operation '%s'.", op)
                reply_status = GIOP.SYSTEM_EXCEPTION
                reply_body = CDR.OutputBuffer()
                CORBA.marshal(reply_body, 'string', 'IDL:CORBA/BAD_OPERATION:1.0')
                CORBA.marshal(reply_body, 'unsigned_long', 13)
                CORBA.marshal(reply_body, 'unsigned_long', 1)   # COMPLETED_NO
            else:
                srv_op = '_skel_' + op
                (reply_status, reply_body) = getattr(classname, srv_op)(message)
                if reply_status == None:
                    return (None, remaining_data)       # oneway

        reply = CDR.OutputBuffer()
        GIOP.ReplyHeader_1_2(
            request_id=request_header.request_id,
            reply_status=reply_status,
            service_context=IOP.ServiceContextList([])
        ).marshal(reply)
        reply.write(reply_body.getvalue())
        reply_body.close()
        buffer = CDR.OutputBuffer()
        GIOP.MessageHeader_1_1(
            magic='GIOP',
            GIOP_version=GIOP.Version(major=1, minor=2),
            flags=0x01,         # flags : little endian
            message_type=1,     # Reply
            message_size=len(reply.getvalue())
        ).marshal(buffer)
        buffer.write(reply.getvalue())
        reply.close()
        s = buffer.getvalue()
        buffer.close()
        return (s, remaining_data)





import PyIDL as CORBA
import struct
import StringIO

class OutputBuffer(object):

    def __init__(self, buf=None):
        if buf is None:
            buf = StringIO.StringIO()
        self._buf = buf
        self._pos = 0
        self._endian = 1    # little endian

    def _get_endian(self):
        return self._endian

    endian = property(fget=_get_endian)

    def getvalue(self):
        return self._buf.getvalue()

    def close(self):
        self._buf.close()

    def write(self, str):
        self._buf.write(str)

    def _align(self, size):
        while (self._pos % size) != 0:
            self._buf.write(chr(0))
            self._pos += 1

    def _pack(self, fmt, value):
        str = struct.pack(fmt, value)
        self._buf.write(str)
        self._pos += len(str)

    def char__marshal(self, value):
        self._pack('c', value)

    def wchar__marshal(self, value):
        raise NotImplementedError

    def octet__marshal(self, value):
        self._pack('B', value)

    def short__marshal(self, value):
        self._align(2)
        self._pack('h', value)

    def unsigned_short__marshal(self, value):
        self._align(2)
        self._pack('H', value)

    def long__marshal(self, value):
        self._align(4)
        self._pack('l', value)

    def unsigned_long__marshal(self, value):
        self._align(4)
        self._pack('L', value)

    def long_long__marshal(self, value):
        self._align(8)
        self._pack('q', value)

    def unsigned_long_long__marshal(self, value):
        self._align(8)
        self._pack('Q', value)

    def float__marshal(self, value):
        self._align(4)
        self._pack('f', value)

    def double__marshal(self, value):
        self._align(8)
        self._pack('d', value)

    def long_double__marshal(self, value):
        raise NotImplementedError

    def boolean__marshal(self, value):
        if value == True:
            self._pack('B', 1)
        else:
            self._pack('B', 0)

    def string__marshal(self, value):
        self._align(4)
        value += chr(0)
        length = len(value)
        self._pack('L', length)
        self._pack(str(length) + 's', value)

    def wstring__marshal(self, value):
        raise NotImplementedError


class InputBuffer(object):

    def __init__(self, input=None, endian=None):
        if input == None:
            self._buf = StringIO.StringIO('')
        if isinstance(input, str):
            self._buf = StringIO.StringIO(input)
        else:
            self._buf = input
        self._pos = 0
        self._endian = endian

    def _set_endian(self, value):
        self._endian = value

    def _get_endian(self):
        return self._endian

    endian = property(fset=_set_endian, fget=_get_endian)

    def getvalue(self):
        return self._buf.getvalue()

    def close(self):
        self._buf.close()

    def read(self, size=-1):
        return self._buf.read(size)

    def _align(self, size):
        while (self._pos % size) != 0:
            dummy = self._buf.read(1)
            self._pos += 1

    def _unpack(self, fmt):
        size = struct.calcsize(fmt)
        chunk = self._buf.read(size)
        if len(chunk) < size:
            print "Not enough data!"
            raise CORBA.SystemException('IDL:CORBA/INTERNAL:1.0', 8, CORBA.CORBA_COMPLETED_MAYBE)
        self._pos += size
        return struct.unpack(fmt, chunk)[0]

    def char__demarshal(self):
        return self._unpack('c')

    def wchar__demarshal(self):
        raise NotImplementedError

    def octet__demarshal(self):
        return self._unpack('B')

    def short__demarshal(self):
        self._align(2)
        return self._unpack('h')

    def unsigned_short__demarshal(self):
        self._align(2)
        return self._unpack('H')

    def long__demarshal(self):
        self._align(4)
        return self._unpack('l')

    def unsigned_long__demarshal(self):
        self._align(4)
        return self._unpack('L')

    def long_long__demarshal(self):
        self._align(8)
        return self._unpack('q')

    def unsigned_long_long__demarshal(self):
        self._align(8)
        return self._unpack('Q')

    def float__demarshal(self):
        self._align(4)
        return self._unpack('f')

    def double__demarshal(self):
        self._align(8)
        return self._unpack('d')

    def long_double__demarshal(self):
        raise NotImplementedError

    def boolean__demarshal(self):
        return self._unpack('B') == 1

    def string__demarshal(self):
        self._align(4)
        length = self._unpack('L')
        s = self._unpack(str(length) + 's')
        return s[:len(s)-1]

    def wstring__demarshal(self):
        raise NotImplementedError





from _Calc_skel import *

class MyCalc(Calc_skel):
	""" Implementation of Interface: IDL:Calc:1.0 """

	def Add(self, a, b):
		res = a + b
		print "Add %d + %d => %d" % (a, b, res)
		return res

	def Sub(self, a, b):
		res = a - b
		print "Sub %d - %d => %d" % (a, b, res)
		return res

	def Mul(self, a, b):
		res = a * b
		print "Mul %d x %d => %d" % (a, b, res)
		return res

	def Div(self, a, b):
		if b == 0 :
			print "Div %d / %d => DivisionByZero" % (a, b)
			raise Calc_skel.DivisionByZero()
		else :
			res = a / b
			print "Div %d / %d => %d" % (a, b, res)
			return res



#!/usr/bin/env python -w

from MyCalc import *
import PyIDL.rpc_giop as RPC_GIOP
import SocketServer

class Giopd(SocketServer.BaseRequestHandler):
	def handle(self):
		global servant
		while True :
			request = self.request.recv(1024)
			if len(request) != 0 :
				print "data (%d) received" % len(request)
				(reply, reminder) = servant.Servant(request)
				if reply != None :	# !oneway
					self.request.sendall(reply)
		self.request.close()


servant = RPC_GIOP.Servant()
myCalc = MyCalc()
servant.Register(myCalc.corba_id(), myCalc)

SocketServer.TCPServer.allow_reuse_address = True 
srv = SocketServer.TCPServer(('', 12345), Giopd)
print "Waiting ..."
srv.serve_forever()



from distutils.core import setup

setup(
    name='PyIDL',
    version='0.39',
    description='CORBA-IDL runtime',
    author='Francois Perrad',
    author_email='francois.perrad@gadz.org',
    license='Artistic',
    packages=['PyIDL'],
)




import unittest

import Cplx

class Test(unittest.TestCase):
	def setUp(self):
		self.c1 = Cplx.Complex(1.0, 3.0)
		self.c2 = Cplx.Complex(2.0, -1.0)
		self.calc = Cplx.CalcCplx()

	def tearDown(self):
		del self.c1
		del self.c2
		del self.calc

	def test0(self):
		self.assertEqual(self.c1.re, 1.0)
		self.assertEqual(self.c1.im, 3.0)
		self.assertNotEqual(self.c1, self.c2)

	def test1(self):
		result = self.calc.Add(self.c1, self.c2)
		self.assertEqual(result.re, 3.0)
		self.assertEqual(result.im, 2.0)

	def test2(self):
		result = self.calc.Sub(self.c1, self.c2)
		self.assertEqual(result.re, -1.0)
		self.assertEqual(result.im, 4.0)

if __name__ == '__main__' :
	unittest.main()




from _Calc import *

class MyCalc(Calc):

    def Add(self, val1, val2):
        res = val1 + val2
        print "Add %d + %d => %d" % (val1, val2, res)
        return res
    
    def Div(self, val1, val2):
        if val2 == 0 :
            print "Div %d / %d => DivisionByZero" % (val1, val2)
            raise Calc.DivisionByZero()
        else:
            res = val1 / val2
            print "Div %d / %d => %d" % (val1, val2, res)
            return res

    def Mul(self, val1, val2):
        res = val1 * val2
        print "Mul %d * %d => %d" % (val1, val2, res)
        return res

    def Sub(self, val1, val2):
        res = val1 - val2
        print "Sub %d - %d => %d" % (val1, val2, res)
        return res
